pub enum BootstrapChannel {
CDN {
url: String,
provider: String,
},
Telegram {
bot_username: String,
token: Option<String>,
},
GitHub {
repo: String,
asset_name: String,
},
IPFS {
hash: String,
gateway: Option<String>,
},
Email {
address: String,
subject_pattern: String,
},
}Expand description
Multi-channel bootstrap descriptor distribution.
Each channel represents a different method to fetch bootstrap descriptors. Using multiple channels makes it harder for censors to block all distribution points.
Variants
CDN
CDN-based distribution (e.g., Cloudflare, AWS CloudFront)
Telegram
Telegram bot-based distribution
Fields
GitHub
GitHub releases/assets distribution
Fields
IPFS
IPFS-based distribution (content-addressed)
Fields
Email-based distribution (for enterprise deployments)
Implementations