ControlPayload

Enum ControlPayload 

pub enum ControlPayload {
Show 17 variants KeyRotate { new_eph_pub: [u8; 32], }, MaskUpdate { mask_data: Vec<u8>, signature: [u8; 64], }, Keepalive, TelemetryRequest { metric_flags: u8, }, TelemetryResponse { packet_loss: u16, rtt_ms: u16, jitter_ms: u16, buffer_pct: u8, }, TimeSync { server_ts_ms: u64, }, Shutdown { reason: u8, }, ControlAck { ack_seq: u16, ack_for_subtype: u8, }, ServerHello { server_eph_pub: [u8; 32], signature: [u8; 64], network_config: Option<ClientNetworkConfig>, }, RecordingStart { service: String, }, RecordingAck { session_id: [u8; 16], status: String, }, RecordingStop { session_id: [u8; 16], }, RecordingComplete { service: String, mask_id: String, confidence: f32, }, RecordingFailed { reason: String, }, RecordingStatusRequest, RecordingStatus { can_record: bool, active_service: Option<String>, }, BootstrapDescriptorUpdate { descriptor_data: Vec<u8>, },
}
Control message payload

Variants



KeyRotate

Fields

new_eph_pub: [u8; 32]


MaskUpdate

Fields

mask_data: Vec<u8>
signature: [u8; 64]


Keepalive



TelemetryRequest

Fields

metric_flags: u8


TelemetryResponse

Fields

packet_loss: u16
rtt_ms: u16
jitter_ms: u16
buffer_pct: u8


TimeSync

Fields

server_ts_ms: u64


Shutdown

Fields

reason: u8


ControlAck

Fields

ack_seq: u16
ack_for_subtype: u8


ServerHello

Fields

server_eph_pub: [u8; 32]
signature: [u8; 64]
network_config: Option<ClientNetworkConfig>


RecordingStart

Admin requests recording start for a service

Fields

service: String


RecordingAck

Server acknowledges recording start

Fields

session_id: [u8; 16]
status: String


RecordingStop

Admin requests recording stop

Fields

session_id: [u8; 16]


RecordingComplete

Server reports mask generation complete

Fields

service: String
mask_id: String
confidence: f32


RecordingFailed

Server reports recording/generation failure

Fields

reason: String


RecordingStatusRequest

Client asks whether the current authenticated session may record masks.



RecordingStatus

Server reports recording capability and current active recording state.

Fields

can_record: bool
active_service: Option<String>


BootstrapDescriptorUpdate

Fields

descriptor_data: Vec<u8>

Implementations

Source

impl ControlPayload

pub fn encode(&self) -> Result<Vec<u8>>

pub fn decode(data: &[u8]) -> Result<Self>