BootstrapChannel

Enum BootstrapChannel 

pub enum BootstrapChannel {
    CDN {
        url: String,
        provider: String,
    },
    Telegram {
        bot_username: String,
        token: Option<String>,
    },
    GitHub {
        repo: String,
        asset_name: String,
    },
    IPFS {
        hash: String,
        gateway: Option<String>,
    },
    Email {
        address: String,
        subject_pattern: String,
    },
}
Multi-channel bootstrap descriptor distribution.

Each channel represents a different method to fetch bootstrap descriptors. Using multiple channels makes it harder for censors to block all distribution points.

Variants



CDN

CDN-based distribution (e.g., Cloudflare, AWS CloudFront)

Fields

url: String

CDN URL endpoint

provider: String

CDN provider name for logging/analytics



Telegram

Telegram bot-based distribution

Fields

bot_username: String

Telegram bot username

token: Option<String>

Bot token (optional, can use public bot)



GitHub

GitHub releases/assets distribution

Fields

repo: String

Repository in format “owner/repo”

asset_name: String

Asset name pattern (e.g., “bootstrap-descriptors-v*.json”)



IPFS

IPFS-based distribution (content-addressed)

Fields

hash: String

IPFS content hash (CID)

gateway: Option<String>

Gateway URL (optional, uses default gateway if None)



Email

Email-based distribution (for enterprise deployments)

Fields

address: String

Email address to request descriptors from

subject_pattern: String

Subject line pattern for automated requests

Implementations

Source

impl BootstrapChannel

pub fn name(&self) -> &str

Get a human-readable name for this channel

pub fn channel_type(&self) -> &str

Get the channel type name